@@ -148,8 +148,6 @@ def get_instance_info(instances, class_instance):
             if class_instance.hint:
                 if matching_hint:
                     sys.stdout.write(description + '\n')
-                else:
-                    print("no matching instances")
             else:
                 sys.stdout.write(description + '\n')
         else:
@@ -157,8 +155,6 @@ def get_instance_info(instances, class_instance):
                 if matching_hint:
                     print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
                     print("-------")
-                else:
-                    print(cs("no instances found.", "yellow"))
             else:
                 print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
                 print("-------")
